#
# spec file for package fastfetch
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fastfetch
Version:        2.38.0
Release:        1.2
Summary:        Neofetch-like tool written mostly in C
License:        MIT
URL:            https://github.com/fastfetch-cli/fastfetch
Source:         https://github.com/fastfetch-cli/fastfetch/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  Mesa-devel
BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  opencl-headers
BuildRequires:  vulkan-headers
# For some reason these don't build on Leap
%if 0%{?suse_version} > 1600
%ifarch %{ix86} x86_64
BuildRequires:  pkgconfig(DirectX-Headers)
%endif
%endif
BuildRequires:  pkgconfig(ImageMagick)
BuildRequires:  pkgconfig(chafa)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dconf)
BuildRequires:  pkgconfig(ddcutil)
BuildRequires:  pkgconfig(libelf)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libxfconf-0)
BuildRequires:  pkgconfig(ocl-icd)
BuildRequires:  pkgconfig(rpm)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(vulkan)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(zlib)
Recommends:     ImageMagick
Recommends:     Mesa
Recommends:     chafa
Recommends:     dbus-1
Recommends:     dconf
Recommends:     glib2-tools
Recommends:     pciutils
Recommends:     rpm
Recommends:     sqlite3
Recommends:     vulkan-tools
Recommends:     xfconf
Recommends:     xrandr
Recommends:     zlib

%description
Fastfetch is a neofetch-like tool for fetching system information and
displaying them in a pretty way.  It is written mainly in C, with performance and
customizability in mind. Currently Linux, Android, FreeBSD,
MacOS and Windows 7+ are supported.

%package        fish-completion
Summary:        Fish Completion for %{name}
Supplements:    (%{name} and fish)
Requires:       fastfetch
Requires:       fish
BuildArch:      noarch

%description    fish-completion
Fish command-line completion support for %{name}.

%package        bash-completion
Summary:        Bash Completion for %{name}
Supplements:    (%{name} and bash-completion)
Requires:       bash-completion
Requires:       fastfetch
BuildArch:      noarch

%description    bash-completion
Bash command-line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Supplements:    (%{name} and zsh)
Requires:       fastfetch
Requires:       zsh
BuildArch:      noarch

%description    zsh-completion
Zsh command-line completion support for %{name}.

%prep
%autosetup

%build
%cmake -DBUILD_FLASHFETCH:BOOL=FALSE
%cmake_build

%install
%cmake_install

%files
%license LICENSE
%doc README.md CHANGELOG.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/%{name}/

%files bash-completion
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/fastfetch

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/fastfetch.fish

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_fastfetch

%changelog
* Mon Mar  3 2025 RN <R_Nik_C@proton.me>
- update to 2.38.0
  Bugfixes:
  * Fix empty battery slots handling
    (gh#fastfetch-cli/fastfetch#1575)
  * Fix `{day-pretty}` output in custom format (DateTime, Windows)
  * Fix VanillaOS detection (OS, Linux)
  * Fix secure boot testing (gh#fastfetch-cli/fastfetch#1584)
  * Fix the SI unit "kB" in help message
    (gh#fastfetch-cli/fastfetch#1589)
  * Fix segfault on macOS 10.15 when using the binary downloaded
    from Github Releases (gh#fastfetch-cli/fastfetch#1594)
  Features:
  * Support Chassis module in macOS (Chassis, macOS)
  * Allow customize key format with kernel name and distro name (OS)
  * Add missing `{icon}` in custom key format (Battery)
  * Add missing `{mountpoint}` and `{mount-from}` in custom output
    format (gh#fastfetch-cli/fastfetch#1577)
  * Support percentage num & bar in custom format
    (gh#fastfetch-cli/fastfetch#1583)
  * Support `pisi` package manager detection (Packages, Linux)
  * Support termite terminal font detection (TerminalFont, Linux)
  * Report monitor type in Brightness module (Brightness)
  Logo:
  * Add `opensuse-tumbleweed_small`
  * Add `Bedrock_small`
  * Add `fastfetch`
  * Remove some unnecessary distro names
* Wed Feb 19 2025 RN <R_Nik_C@proton.me>
- update to 2.37.0
  Changes:
  * Option `--escape-bedrock` is removed. The function is always
    enabled now.
  Features:
  * Support for Haiku is greatly improved (Haiku)
  - CPU, GPU, Disk, Sound, Terminal, Terminal Font, Init System,
    Battery, Mouse, Keyboard, NetIO, CPU Usage, Physical Disk
    and OpenGL should work on Haiku now
  - SMBIOS related modules (Host, Bios, Board, Chassis, Physical
    Memory) should work in platforms with legacy BIOS system.
  - Support for Gamepad and Bluetooth are WIP.
  - Some bugs are found and fixed.
  * Remove `python-requests` dependency in `scripts/gen-*.py`.
  * Add cmake option `-DENABLE_EMBEDDED_AMDGPUIDS=BOOL` (disabled
    by default)
  - If enabled, fastfetch will embed the newest `amdgpu.ids`
    file into fastfetch binary.
  * Weather module now honors `display.temp.unit` option
  * Support Physical Memory module in NetBSD (PhysicalMemory,
    NetBSD)
  - Requires root permission
  * Improve non-intel CPU detection in NetBSD
    (gh#fastfetch-cli/fastfetch#1573, CPU, NetBSD)
  Bugfixes:
  * Fix building in macOS 10.13 (GPU, macOS)
  * Properly round percent values when detecting volume
    (gh#fastfetch-cli/fastfetch#1558, Sound)
  * Fix Physical Memory module doesn't work in `--format json` mode
  * Add some missing variable inits (GPU, Linux)
  * Fix `--localip-default-route-only false` not working with
    `--gen-config` (gh#fastfetch-cli/fastfetch#1570, LocalIP)
  Logo:
  * Update Rosa linux
  * Add Haiku2
* Tue Feb 11 2025 RN <R_Nik_C@proton.me>
- update to 2.36.1
  Changes:
  * To use the native arm64 runner of Github Action, Linux
    aarch64 binary is now built with Ubuntu 22.04 (Glibc 2.35,
    Debian 12).
  Bugfixes:
  * Chimera Linux logo is now displayed correctly
    (gh#fastfetch-cli/fastfetch#1554, Logo)
  - Regression of 2.36.0
  * Fix building on Haiku
  Logo:
  * Fix ALT Linux
* Mon Feb 10 2025 RN <R_Nik_C@proton.me>
- update to 2.36.0
  Bugfixes:
  * Trim leading slash for login shells (Shell, OpenBSD)
  * Prefer SOC name if available over CPU name (CPU, Linux)
  Features:
  * Use kernel API to detect sound devices (Sound, NetBSD)
  * Use sndio for sound server detection on OpenBSD (Sound,
    OpenBSD)
  * Add minimal implementation for Haiku
    (gh#fastfetch-cli/fastfetch#1538, Haiku)
  * Support CPU & GPU temperature detection for M4x (CPU / GPU,
    macOS)
  * Support VMEM size detection for old Nvidia cards (GPU, Linux)
  * Use recommendedMaxWorkingSetSize as total GPU mem size (GPU,
    macOS)
  * Support Physical core count and CPU package count detection
    for loongarch (CPU, Linux)
  * Split ID_LIKE when used for distro matching
    (gh#fastfetch-cli/fastfetch#1540, Logo)
  * Capitalize `{type}`'s first letter in custom format
    (gh#fastfetch-cli/fastfetch#1543, Display)
  * Support model name detection for s390x (CPU, Linux)
  * Support more Armbian variants detection
    (gh#fastfetch-cli/fastfetch#1547, OS, Linux)
  * Support the syntax of {$ENV_VAR} in custom format, which will
    be replaced by the value of the environment variable ENV_VAR
    (gh#fastfetch-cli/fastfetch#1541)
  - This is another way to pass 3rd-party data to fastfetch
    besides `Custom` module.
  * Improve performance of Tilix version detection (Terminal,
    Linux)
  Logo:
  * Update arch_old
  * Add Nexa Linux
  * Add filotimo
  * Update some distro names
* Mon Jan 27 2025 RN <R_Nik_C@proton.me>
- update to 2.35.0
  Bugfixes:
  * Suppress output of EGL again (gh#fastfetch-cli/fastfetch#1513)
  - Regression of 2.34.0
  Features:
  * Show SOC name reported in `cpuinfo` if available
    (gh#fastfetch-cli/fastfetch#1510, CPU, Linux)
  * Change package manager name of NetBSD from pkg to pkgsrc
    (gh#fastfetch-cli/fastfetch#1515, Packages, NetBSD)
  * Detect SOC name on RISCV (gh#fastfetch-cli/fastfetch#1519,
    CPU, Linux)
  * Report marketing name of new QS8Es (CPU, Android)
  * Acquire acquire more os info from lsb-release if missing from
    os-release (gh#fastfetch-cli/fastfetch#1521)
  * CMake: add option `-DCUSTOM_LSB_RELEASE_PATH` to specify the
    path of `lsb-release` file
  - `-DCUSTOM_OS_RELEASE_PATH` has been supported since v2.11.4
  * Report more SOC names on Android (CPU, Android)
  * Support duration printing in custom format (Disk / Users)
  Logo:
  * Add Arch_old
  * Update key color of NetBSD_small
  * Fix OpenBSD and many other ascii logos
    (gh#fastfetch-cli/fastfetch#1522)
* Mon Jan 13 2025 RN <R_Nik_C@proton.me>
- update to 2.34.1
  Features:
  * Report vendor name when detecting GPUs by OpenGL
  - Note: the vendor name is actually the creator of the OpenGL
    driver (such as `Mesa`) and may not be the same as the GPU
    vendor
  Bugfixes:
  * Fix Ghostty termfont detection
    (gh#fastfetch-cli/fastfetch#1495)
  * Fix compatibility with KDE Plasma 6.3
    (gh#fastfetch-cli/fastfetch#1504)
  * Make memory usage detection logic consistent with other
    systems (Memory, OpenBSD / NetBSD)
  * Report media file name if media title is not available (Media)
  * Fix max frequency detection for CPUs with both performance and
    efficiency cores (CPU, FreeBSD)
  Logo:
  * Add HeliumOS
  * Add Oreon
  * Update SnigdhaOS
* Thu Jan  9 2025 RN <R_Nik_C@proton.me>
- update to 2.34.0
  Changes:
  * We now print distro pretty name if available (OS)
  - This is a long requested feature. However, it may break
    some distros. File a bug with the content of
    `/etc/os-release` if it breaks your distro
  Bugfixes:
  * Fix thunderbolt version of new MBPs
    (gh#fastfetch-cli/fastfetch#1465, Host, macOS)
  * Fix backlight name detection on FreeBSD (Brightness, FreeBSD)
  * Fix Terminal detection when running fastfetch in
    `pk-command-not-found`
    (gh#fastfetch-cli/fastfetch#1467, Terminal, Linux)
  * Relax detection of terminals in NixOS
    (gh#fastfetch-cli/fastfetch#1479, Terminal, Linux)
  - Should fix konsole, ghostty and maybe others
  * Fix core count output in multi-package platforms (CPU)
  * Don't suppress the output of preRun
    (gh#fastfetch-cli/fastfetch#1489)
  * Fix battery percentage detection (Battery, NetBSD)
  Features:
  * Support ghostty terminal font detection (TerminalFont, Linux /
    macOS)
  * Support `kitty-icat` image protocol, which uses `kitten icat`
    to generate image data
  - Pros: support tmux; support gif animations; good performance
  - Cons: due to the limitation of `kitten icat`, we need to
    clear the screen before displaying the image logo
  * Support WM version detection (WM)
  - In Linux, Hyprland & sway are supported currently
  * Improve performance when stdout is redirected (TerminalSize)
  * Report thermal zone temp if CPU temp is not available (CPU,
    Linux)
  * Report sound server (Pipewire or PulseAudio) if available
    (gh#fastfetch-cli/fastfetch#1454, Sound, Linux)
  * Enable OpenGL & OpenCL detection on Android (OpenGL / OpenCL,
    Android)
  * Detect & report MediaTek Dimensity 9000+ SOC name (CPU, Android)
  * Support appman (am-user) package manager detection (Packages,
    Linux)
  Logo:
  * Add Lubuntu
  * Update Xray_os
  * Add SnigdhaOS
  * Add Rhino Linux
* Thu Dec 26 2024 RN <R_Nik_C@proton.me>
- Excluded flashfetch binary
- update to 2.33.0
  Changes:
  * Introduce a new CMake flag `-DBUILD_FLASHFETCH=OFF` to
    disable building flashfetch binaries
  - Package managers are encouraged to enable it.
  Bugfixes:
  * Fix interconnect type detection
    (gh#fastfetch-cli/fastfetch#1453, PhysicalDisk)
  - Regression of v2.28
  * Don't report `proot` as terminal (Terminal, Android)
  * Remove a debug output (DiskIO, OpenBSD)
  * Fix media detection for some players
    (gh#fastfetch-cli/fastfetch#1461, Media)
  - Regression of v2.32
  Features:
  * Use `$POWERSHELL_VERSION` as PowerShell version if available
    (Shell)
  - Fetching Windows PowerShell version can be very slow. Add
    `$env:POWERSHELL_VERSION = $PSVersionTable.PSVersion.ToString()`
    in $PROFILE before running fastfetch to improve the performance
    of Shell module
  * Add support for ubuntu-based armbian detection
    (gh#fastfetch-cli/fastfetch#1447)
  * Improve performance of Bluetooth detection (Bluetooth)
  - We no longer report disconnected bluetooth devices in
    `--format json` when `--bluetooth-show-disconnected` isn't
    specified
  * Support brightness level detection for builtin displays
    (Brightness, OpenBSD / NetBSD)
  - Requires root permission on OpenBSD
  * Support battery level detection (Battery, OpenBSD / NetBSD)
  * Support CPU temperature detection in NetBSD (CPU, NetBSD)
  * Hard code path of `libvulkan.so` for Android
  - So that users don't need to install the vulkan-loader wrapper
    of termux
  Logo:
  * Add NurOS
  * Add GoralixOS
* Wed Dec 18 2024 RN <R_Nik_C@proton.me>
- update to 2.32.1
  Bugfixes:
  * Fix `pci.ids` file location on OpenBSD (GPU, OpenBSD)
  - It's normally unused because enumerating PCI devices on
    OpenBSD requires root privileges
  * Fix bssid formatting (Wifi, Linux)
  * Fix Linux Lite distro detection
    (gh#fastfetch-cli/fastfetch#1434, OS, Linux)
  * Suppress XE driver warnings from Mesa
    (gh#fastfetch-cli/fastfetch#1435, OpenGL, Linux)
  * Fix format parameter name
    (gh#fastfetch-cli/fastfetch#1443, Version)
  * Don't report useless information when Wifi is disabled (Wifi,
    FreeBSD)
  - Currently there are issues when the SSID contains
    whitespaces. More fixes are expected in the future
  * Always use physical size reported by X11 server to avoid
    inconsistent results (gh#fastfetch-cli/fastfetch#1444,
    Display, Linux)
  * Fix package count detection on OpenBSD (Packages, OpenBSD)
    [2.32.1]
  Features:
  * Randomly select one if the logo source expands to multiple
    files (gh#fastfetch-cli/fastfetch#1426, Logo)
  * Report mac product name when running Linux in MacBook (Host,
    Linux / FreeBSD)
  * Use screen size reported in DTD if make sense (Display)
  * Detect Virtualized Apple Silicon CPUs (CPU, Linux)
  * Add detection support for fvwm and ctwm (WM, OpenBSD / NetBSD)
  * Add Armbian-unofficial detection (OS, Linux)
  * Prefer surfaceless display when connect EGL (OpenGL)
  * Improve accuracy of WM detection on FreeBSD (WM, FreeBSD)
  * Add ratpoison window manager (WM, Linux)
  Logo:
  * Update Linux Lite
  * Add Serpent OS
  * Add Ultramarine Small
  * Update Debian
* Tue Dec  3 2024 RN <R_Nik_C@proton.me>
- update to 2.31.0
  Bugfixes:
  * Improve performance of media detection; fix musikcube
    detection (Media, Linux)
  - After the change, `general.processingTimeout` will also
    control the timeout of dbus remote calls
  * Fix invalid variable names
    (gh#fastfetch-cli/fastfetch#1408, Users)
  * Change physical size detection to use basic display parameters
    (gh#fastfetch-cli/fastfetch#1406)
  * Fix possible sigfaults when detecting displays
    (gh#fastfetch-cli/fastfetch#1393)
  * Fix Nvidia card type detection
  * Fix wl-restart parsing (gh#fastfetch-cli/fastfetch#1422, WM,
    Linux)
  * Fix syntax error in completion file
    (gh#fastfetch-cli/fastfetch#1421)
  * Fix hunging when using ssh-agent as command text
    (gh#fastfetch-cli/fastfetch#1418, Command, macOS)
  Features:
  * Remove support of xcb & xlib and xrandr extension is always
    required (Display)
  * Support preferred resolution & refresh rate detection
  - On macOS there is no preferred resolution reported and
    maximum available resolution is reported instead.
  - `--display-format {preferred-width}x{preferred-height}
    @{preferred-refresh-rate}`
  * Report scale factor in custom format (Display)
  - `--display-format {scale-factor}`
  * Detect current Wi-Fi channel and maximum frequency (Wifi)
  * Report processor package count
    (gh#fastfetch-cli/fastfetch#1413, CPU)
  * Remove duplicate whitespaces in CPU name
  * Support sakura terminal version & font detection
    (Terminal / TerminalFont, Linux)
  Logo:
  * Fix LMDE
  * Update MidOS
  * Add Windows Server 2025
* Tue Nov 19 2024 RN <R_Nik_C@proton.me>
- update to 2.30.1
  * A hotfix release that fixes a build failure when running cmake
    outside of build directory.
- update to 2.30.0
  Changes:
  * Percent: bar type must be enabled in `percent.type` before
    using percent bar in custom format
  Features:
  * Port to MidnightBSD; add mport package manager support
  * Support bluetooth battery detection for macOS and Windows
    (Bluetooth, macOS / Windows)
  * Support M4 model detection (Host, macOS)
  * Support CPU temperature detection on OpenBSD (CPU, OpenBSD)
  * Display Android icon in Android devices (OS, Android)
  * Support qi package manager detection (Packages, Linux)
  * Detect WM / DE by enumerating running processes (WM / DE,
    NetBSD)
  * Generate manual pages from help.json (Doc)
  * Detect marketing name of vivo smartphone (Host, Android)
  * Add txDrops detection if supported (NetIO, *BSD)
  * Support tilix version detection (Terminal, Linux)
  * Support percent type config in module level.
  Bugfixes:
  * Don't display `()` in key if display name is not available
    (Display)
  * Fix & normalize bluetooth mac address detection (Bluetooth,
    macOS / Windows)
  * Don't print index in multi-battery devices (Battery)
  * Fix segfault in macOS (gh#fastfetch-cli/fastfetch#1388, macOS)
  * Fix `CFStringGetCString() failed` errors
    (gh#fastfetch-cli/fastfetch#1394, Media, macOS)
  * Fix CPU frequency detection on Apple M4
    (gh#fastfetch-cli/fastfetch#1394, CPU, macOS)
  * Fix exe path detection on macOS (Shell / Terminal, macOS)
  * Fix logo fails to load from symlinked files on macOS
    (gh#fastfetch-cli/fastfetch#1395, Logo, macOS)
  * Fix 32-bit truncation (NetIO, macOS)
  Logos:
  * Fix Lilidog
  * Add MidnightBSD
  * Add Unifi
  * Add Cosmic DE
  * Update openSUSE Tumbleweed
* Mon Nov  4 2024 RN <R_Nik_C@proton.me>
- update to 2.29.0
  Features:
  * Port to NetBSD and DragonFly BSD
  - Fastfetch now supports all major BSD variants
  * Support DiskIO, NetIO, GPU and Users module on OpenBSD
  * Report SD8E SOC name (CPU, Android)
  * On Windows, try loading dlls from current exe path (Windows)
  - Fix Media module when installed with winget
  Bugfixes:
  * Fix the VIM version detection on Ubuntu (Editor, Linux)
  * Improve performance of OS version detection on Proxmox
    (gh#fastfetch-cli/fastfetch#1370, OS, Linux)
  Logo:
  * Update OpenSuse Tumbleweed
  * Add XCP-ng
  * Add SummitOS
  * Add Lilidog
  * Update PikaOS
  * Update OpenSUSE Leap
  * Update aperture
* Wed Oct 23 2024 RN <R_Nik_C@proton.me>
- update to 2.28.0
  Changes:
  * Due to the upstream removal of MSYS2 CLANG32 environment,
    `fastfetch-windows-i686` is now built with the ancient and
    untested MSVCRT. Unknown bugs are expected
  Features:
  * Add new module `Mouse` and `Keyboard` which display connected
    mice and keyboards
  * Support remaining time detection (Battery)
  * Report if AC is connected (Battery, Linux)
  * Report platform API used for display detection for debugging
    (Display)
  * Report Wine version when running in Wine (Kernel, Windows)
  * Add option `waitTime` in modules `CPUUsage`, `DiskIO` and
    `NetIO`
  Bugfixes:
  * Fix used memory size detection (Memory, OpenBSD)
  * Don't report invalid fragmentation percentage when fails to
    detect it (Zpool)
  * Fix unexpected errors when running fastfetch in parallel
    (gh#fastfetch-cli/fastfetch#1346, Windows)
  * Don't report obviously invalid temperature values
    (PhysicalDisk, Linux)
  Logos:
  * Add eweOS
  * Add MidOS
  * Update XeroArch
* Sun Oct  6 2024 RN <R_Nik_C@proton.me>
- update to 2.27.1
  Changes:
  * We now print " instead of ″ when displaying diagonal length
    in inches, so that the character can be correctly displayed
    in Linux console (Display)
  * All detection code of `monitor` module is merged into `display`
    module. Now `monitor` just prints the same information as `
    display` with different format. Notably:
  - The resolution reported by monitor module is now current
    resolution instead of native / maximum resolution. PPI is
    calcuated based on current resolution too
  - The refresh rate reported by `monitor` module is the
    current refresh rate
  Features:
  * Add initial support of OpenBSD (OpenBSD)
  * Improve support for Raspberry pi (CPU / GPU, Linux)
  * Detect SOC name, instead of displaying components used in the
    SOC, if available (CPU, Linux)
  * Add option `--brightness-compact` to display multiple
    brightness values in one line (Brightness)
  * Add `day-pretty` (gh#fastfetch-cli/fastfetch#1305, DateTime)
  * Support network interface adapter flag detection
    (gh#fastfetch-cli/fastfetch#1315, LocalIP)
  - Enable it with `--localip-show-flags`
  Bugfixes:
  * Remove trailing newline in GPU name for Raspberry pi
    (gh#fastfetch-cli/fastfetch#1303, GPU, Linux)
  * Fix a possible buffer overflow (GPU, Linux)
  * Fix CPU temp incorrectly reported as 0 celsius
    (gh#fastfetch-cli/fastfetch#1308, CPU, Linux)
  * Corrently report TPM device is not found error
    (gh#fastfetch-cli/fastfetch#1314, TPM, Windows)
  * Fix errors when triggering shell completion with python3
    uninstalled (gh#fastfetch-cli/fastfetch#1310)
  - To package managers: as shell completion scripts of fastfetch
    use python3, it should be added as an optional dependency of
    fastfetch
  * Fix possible crashes when detecting term font of kitty
    (gh#fastfetch-cli/fastfetch#1321, TerminalFont, Linux)
  Logos:
  * Add XeroArch
  * Add ValhallaOS
* Sun Sep 29 2024 RN <R_Nik_C@proton.me>
- update to 2.26.1
  Changes:
  * To be consistent to other platforms, CPU frequency detection
    on Linux no longer checks `bios_limit`
  Features:
  * Detect GPU index (gh#fastfetch-cli/fastfetch#1267, GPU)
  * Count Flatpak runtime packages
    (gh#fastfetch-cli/fastfetch#1085, Packages, Linux)
  * Support `pacstall` package manager (Packages, Linux)
  - CMake `-DPACKAGES_DISABLE_PACSTALL=ON` can be used to disable
  * Support CU core count, max frequency, VMEM usage detection for
    AMD cards on Linux (GPU, Linux)
  - Requires `--gpu-driver-specific`
  * Support EU core count, VMEM size detection Intel cards on Linux
    (GPU, Linux)
  - Requires --gpu-driver-specific. VMEM usage detection requires
    root permissions
  * Add new module TPM to print TPM (Trusted Platform Module)
    version if available (TPM)
  * Support GPU driver version detection (GPU, macOS)
  * Add new CMake option `-DENABLE_EMBEDDED_PCIIDS=<BOOL>`
  - If enabled, fastfetch will download the newest `pci.ids` file,
    transform it into C code and compile it into fastfetch
    binaries
  Bugfixes:
  * Fix font size detecton of foot terminal
    (gh#fastfetch-cli/fastfetch#1276, TerminalFont, Linux)
  * Ignore `su` and `sudo` when detecting terminal
    (gh#fastfetch-cli/fastfetch#1283, Terminal, Linux)
  * Always print inches in integer (Display)
  * Fix Wifi connection protocol detection on macOS Sequoia (Wifi,
    macOS)
  * Fix hanging when font name is long when detecting kitty term font
    (gh#fastfetch-cli/fastfetch#1289, TerminalFont)
  * Detect all enabled or connected connectors
    (gh#fastfetch-cli/fastfetch#1301, Display, Linux)
* Thu Sep 19 2024 Gordon Leung <pirateclip@protonmail.com>
- update to 2.25.0
  Features:
  * Moore Threads GPU add support to query number of cores (GPU)
  * Cache detection result based on last modification time (Packages)
  * Add cmake options to disable certain package managers at compile time
  * Add new option --show-localip-{speed,mtu} (LocalIP)
  * Add new module Btrfs, which prints all mounted Btrfs volumes, like Zpool module (Linux)
  Bugfixes:
  * Fix compiling with old linux headers (Camera, Linux)
* Thu Sep 12 2024 Gordon Leung <pirateclip@protonmail.com>
- update to 2.24.0
  Changes:
  * Support of --lib-XXX is removed
  - If fastfetch fails to load some .so .dylib libraries,
    LD_LIBRARY_PATH should be used.
  Features:
  * Detect more ARM microarchitectures and SOC names (CPU, Linux)
  * Support board name detection for Asahi Linux (Board, Linux)
  * Add new option --command-param to customize the parameters when running shell
  * Support syntax of sub string in --<module>-format: {variable~startIndex,endIndex}
  - See fastfetch -h format for detail
  Bugfixes:
  * Fix tests building when system yyjson is used
  * Fix dinit detection; support dinit version detection (InitSystem, Linux)
  * Fix signal quality, refresh rate and maybe others in custom format
  * Fix boot time calculation (Uptime, Linux)
  * Fix custom format for boolean values
  - `{?false-value}This should not print{?}{?true-value}This should print{?}`
    will print `This should print`
* Tue Sep  3 2024 Gordon Leung <pirateclip@protonmail.com>
- Make completion packages Require the main package
- update to 2.23.0
  Features:
  * Support unity version detection (DE, Linux)
  * Print model name in Battery keys if available (Battery)
  * Add module Zpool
  * Improve performance (Shell / Terminal, Linux)
  * Support syntax of padded strings in --<module>-format. {variable<padlength} and {variable>padlength} are supported.
    If pad length is greater than the length of the variable, the variable will be padded with spaces.
    fastfetch -l none -s command --command-text 'echo 12345' --command-format 'output({1<20})' prints Command: output(12345               )
    fastfetch -l none -s command --command-text 'echo 12345' --command-format 'output({1>20})' prints Command: output(               12345)
    If pad length is less than the length of the variable, the variable will be truncated.
  Bugfixes:
  * Fix broken --list-presets
  * Update zsh completion script
  * Don't print * if defaultRouteOnly is set (NetIO)
  * Fix Camera module incorrectly disabled on FreeBSD (Camera, FreeBSD)
  * Fix hanging on screen 5.0 (Terminal)
* Mon Aug 26 2024 Gordon Leung <pirateclip@protonmail.com>
- update to 2.22.0
  Features:
  * Small performance improvements (Terminal, Editor)
  * Improve arm32 and loongarch support (CPU, Linux)
  * Ignore the parent process if env $FFTS_IGNORE_PARENT is set to 1 (Shell)
  * Add code name of Apple M4 (CPU, Linux)
  * Add ethernet speed rate detection support (LocalIP)
  * Add zsh completion script
  * Add Linglong package manager detection support (Packages, Linux)
  Bugfixes:
  * Fix tmux in linux TTY (Colors)
  * Fix hang in WSL when custom format is used (Disk, Linux)
  * Fix /proc/loadavg parsing (Loadavg, Linux)
  * Disable use of LC_NUMERIC locale settings to fix parsing of decimal numbers
  * Fix possible segfault (DiskIO, Linux)
  * Honor preciseRefreshRate in custom format (Display)
* Thu Aug 15 2024 RN <R_Nik_C@proton.me>
- update to 2.21.3
  Bugfixes:
  * Fix bad Intel Arc GPU name detection, which was supposed to
    be fixed in the last version but the change was reverted
    accidentally (GPU, Linux)
  * Fix arm32 CPU name detection no longer work. Regression of
    2.21.2 (CPU, Linux)
* Thu Aug 15 2024 RN <R_Nik_C@proton.me>
- Added some build libraries
* Wed Aug 14 2024 Gordon Leung <pirateclip@protonmail.com>
- update to 2.21.2
  Features:
  * Support --stat <num_in_ms> to display long running modules in yellow or red
  Bugfixes:
  * Fix bad Intel Arc GPU name and type detection (GPU, Linux)
  * Fix uninited struct fields (GPU, Linux)
  * Skip cpu model smbios detection on ARM platforms (CPU, Linux)
  * Fixing detection of pthread_timedjoin_np (Linux)
* Fri Aug  9 2024 Gordon Leung <pirateclip@protonmail.com>
- update to 2.21.1
  Changes:
  * On Linux, FreeBSD and SunOS, a new recommended dependency
    libelf` is introduced to extract strings in ELF binary, used for
  - st term font detection when the term font is compiled directly into the binary
  - fast path of systemd version detection
  Features:
  * Improve performance of
  - kitty version detection (Terminal, Linux)
  - st term font detection (TerminalFont, Linux)
  - systemd version detection (InitSystem, Linux)
  Bugfixes:
  - Fix building error without `linux/wireless.h` (Wifi, Linux)
  - Fix wrong GPU max frequency on Asahi Linux (GPU, Linux)
  - Don't rely `$XDG_SESSION_TYPE` for detecting wm protocol (WM, Linux)
  - Fix light color doesn't work on Linux console (Colors, Linux)
  - `LC_ALL`, if set, overrides every other locale-related environment variable (Locale)
  - Increase timeout of DBus calls (Linux)
* Mon Aug  5 2024 RN <R_Nik_C@proton.me>
- update to 2.21.0
  Changes:
  * We no longer use libnm for Wifi detection on Linux. Instead, we
    use libdbus to communicate with NetworkManager directly
  - To package managers: libnm dependency should be removed
  Features:
  * Add module `BluetoothRadio` that prints bluetooth radios installed on
    the system
  - Don't confuse with module `Bluetooth` which lists connected
    bluetooth devices
  * Detect more information when `--gpu-driver-specific` is used (GPU)
  * Detect which type of nvidia driver (open source or proprietary) is
    used (GPU, Linux)
  * `--gpu-driver-specific` adds supports for Moore Threads GPU (GPU,
    Linux / Windows)
  * Use SetupAPI for detecting GPUs to support GPU detection when running
    fastfetch as a Windows Service (GPU, Windows)
  - See https://github.com/gpustack/gpustack/pull/97#issuecomment-2264699787
    for detail
  * Detect playback status (Media, Linux)
  Bugfixes:
  * Don't try to connect display server in tty mode (Linux)
  * Improve ssh detection
  * Fix max frequency printing in custom format (CPU)
  * Fix displaying random characters when detecting kitty term font
    (TerminalFont, Linux)
  * Make sure to detect all physical memory devices
  * Don't detect `wl-restart` as WM (WM, Linux)
  * Use PCI bus ID to match Nvidia cards; fix multi-GPU detection (GPU)
  * Ignore invalid GPU (GPU, macOS)
  * Print error when invalid color code is found
  * Fix invalid refresh rate detection on old macOS versions (Display, macOS)
  * Fix disk size detection on 32-bit systems (Disk, BSD)
  * Don't ignore disabled GPUs (GPU, Linux)
  * Fix GPU type detection on FreeBSD (GPU, FreeBSD)
  * Remove shell version detection for unknown shells (Shell)
  * Don't detect hyfetch as shell on NixOS (Shell, NixOS)
  Logos:
  * Update EndeavourOS_small
  * Add QTS
* Fri Jul 26 2024 RN <R_Nik_C@proton.me>
- updaet to 2.20.0
  Changes:
  * JSON option `display.keyWidth` has been renamed to `display.key.width`
  - Previously: `{ "display": { "keyWidth": 3 } }`
  - Now: `{ "display": { "key": { "width": 3 } } }`
  * Windows Terminal font detection in WSL has been removed
  Features:
  * Add option `display.key.type: <enum>` to print icons in keys
  - Supported value string, icon and both. Default to string (don't
    display icons)
  - Example: `{ "display": { "key": { "type": "icon" } } }`
  * Add option `display.key.paddingLeft: <num>` to print left padding
    (whitespaces) in keys
  - Example: `{ "display": { "key": { "paddingLeft": 2 } } }`
  * Add option modules.keyIcon to set icon for specified module
  - Example: `{ "modules": { "type": "command", "keyIcon": "🔑" } }`
  * Report system mono font name for Terminator if used (TerminalFont,
    Linux)
  * Don't require logo height to be set when using `--logo-position right`
  * Report Snapdragon SOC marketing name for newer Android phones (CPU,
    Android)
  * Detect MTK SOC part name (CPU, Android)
  Bugfixes:
  * Don't wake up suspended GPUs when using `--ds-force-drm` (Display,
    Linux)
  * Fix printing editor type in JSON result (Editor)
  * Fix `--logo-padding-*` not working correctly (Logo)
  * Fix possible segfault when detecting GPU frequency (macOS, GPU)
* Tue Jul 23 2024 RN <R_Nik_C@proton.me>
- update to 2.19.1
  Bugfixes:
  * Fix frequency value printing when using custom format (CPU / GPU)
  * Fix display detection for XiaoMi Android phone (Display, Android)
  Features:
  * Detect if HDR mode is enabled for screens (Display)
  - Supported in Windows and Linux (KDE) currently
* Mon Jul 22 2024 RN <R_Nik_C@proton.me>
- update to 2.19.0
  Changes:
  * JSON option `modules.cpu.freqNdigits` has been renamed and moved to
    `display.freq.ndigits`
  - Previously: `{ "modules": { "type": "cpu", "freqNdigits": 2 } }`
  - Now: `{ "display": { "freq": { "ndigits": 2 } } }`
  - This option now affects GPU frequency too
  - By default, frequencies are displayed in GHz. Set
    `display.freq.ndigits` to `-1` to display them in MHz
  * JSON option `display.binaryPrefix` has been moved to
    `display.size.binaryPrefix`
  - Previously: `{ "display": { "binaryPrefix": "IEC" } }`
  - Now: `{ "display": { "size": { "binaryPrefix": "IEC" } } }`
  Features:
  * Print physical diagonal length if supported (Display)
  * Detect display type in X11 mode (Display)
  * Assume displays connected via DisplayPort are external monitors
    (Display, Linux)
  * Support GPU frequency detection for Intel XE driver (GPU, Linux)
  * Detect init system on Android (InitSystem, Android)
  * Use background to display color blocks (Colors)
  - To fix weird vertical black lines in some terminals and match the
    behavior of neofetch
  - Can be reverted to old behavior with `--colors-symbol block`
  * Support Zed terminal version detection (Terminal)
  * Improve wezterm font detection (TerminalFont)
  * Add option `--separator-length`
  * Support GPU frequency detection for Apple Silicon (GPU, macOS)
  * Detect maximum refresh rate
  * Detect if HDR mode is supported and enabled (Windows, Display / Monitor)
  * Support physical monitor info detection for FreeBSD and SunOS (Monitor)
  * Support defining constant strings in JSON config file, which can be used
    to dedupe formattion strings
  Bugfixes:
  * Fix some presets
  * Better detection for XTerm terminal fonts (TerminalFont, Linux)
  * Remove debug output (Windows)
  * Fix command line option --gpu-hide-type doesn't work (GPU)
  * Fix wrong date on Raspbian 10 (DateTime, Linux)
  * Use `brightness` instead of `actuall_brightness` when detecting current
    brightness level (Brightness, Linux)
  - Ref: https://bugzilla.kernel.org/show_bug.cgi?id=203905
  * Fix buffer overflow with long font family names when detecting kitty term
    font (TerminalFont)
  * Fix some typos
  Logos:
  * Update void_small
  * Add ALT Linux
* Thu Jul 11 2024 Gordon Leung <pirateclip@protonmail.com>
- update to 2.18.1
  Changes:
  * --ts-version has been renamed to --detect-version
  - general.detectVersion in JSON config file
  Bugfixes:
  * Fix and improve GPU driver detection (GPU, Linux)
* Wed Jul 10 2024 Pi-Cla <pirateclip@protonmail.com>
- update to 2.18.0
  Changes:
  * Fastfetch no longer prints * (which means it's the default route)
    if defaultRouteOnly is set (LocalIP)
  Bugfixes:
  * Fix some memory leaks
  * Fix compatibility with old Python versions
  * Don't detect frequency for AMD cards (GPU, Linux)
  - Fix possible hang with discrete AMD cards (#1077)
  * Don't print colors in --pipe mode (Separator)
  * Don't print (null) in property locator (PhysicalMemory)
  * Ignore disabled PCI devices (GPU)
  * Fix flag --opengl-library doesn't work (OpenGL)
  Features:
  * Detect revision of USB drives (Disk)
  * Support fractional scale factor detection (Display, Linux)
  * Support primary display detection for KDE and GNOME (Display, Linux)
  * Support percent bar in custom formatting
  * Print signal quality by default (Wifi)
  * Detect used OpenGL library version (OpenGL)
* Thu Jul  4 2024 Gordon Leung <pirateclip@protonmail.com>
- update to 2.17.2
  Changes:
  * Flatpak package count no longer includes runtime packages (Packages, Linux)
  Bugfixes:
  * Fix formattion with multiple batteries (Battery)
  * Fix incorrect size value for large memory sticks (PhysicalMemory)
  * Fix spelling of Qt and LXQt
  * Fix typos
  Features:
  * Support Ptyxis terminal version and font detection (Terminal / TerminalFont, Linux)
  * Improve Cinnamon version detection (DE)
  * Support cinnamon-wayland (WMTheme)
  * --ts-version false will disable editor version detection (Editor)
* Sat Jun 29 2024 RN  <R_Nik_C@proton.me>
- update to 2.17.1
  Bugfixes:
  * Don't generate and install libffwinrt.dll.a on MinGW (Windows)
  * Fix building on Windows when imagemagick support is enabled (Logo, Windows)
  * Don't print GPU frequency with --gpu-temp for Nvidia cards (#1052, GPU)
  - --gpu-driver-specific needs to be specified
  * Print formatted size when --gpu-format is used (#1052, GPU)
  * Ignore QVariant format; fix unreadable Qt font (#1053, Theme, Linux)
  * Fix segfaults with --show-errors and an invalid module (#1055)
  - update to 2.17.0
  Changes:
  * CMake option ENABLE_PROPRIETARY_GPU_DRIVER_API is removed. The GPU driver APIs
    are now enabled by default.
  - The option was introduced to reduce the license concerns. Since all non MIT
    proprietary code has been rewritten manually from scratch, it is no longer necessary.
  - See #533 (comment) for detail
  * Option --logo-separate true is changed to --logo-position top for better readability
  - Builtin ascii logos can be positioned on the right side now with --logo-position right
  Features:
  * Add support for --gpu-detection-method opencl which uses OpenCL to detect GPUs.
  * Support detecting CPU cache size by using SMBIOS as fallback (CPUCache)
  * Support GPU detection (SunOS)
  * Support GPU type detection with AMD GPU driver (GPU, Windows)
  * Add fast path of version and font detection for kitty (Terminal / TerminalFont)
  * Make sure stdin and stdout are TTYs when querying terminal
  - So modules like TerminalSize should work when stdin or stdout is redirected
  * Support argument truncation in --<module>-format (#1043)
  - See fastfetch --help format for detail
  * Improve Qt theme detection (#1047, Theme, Linux)
  * Add new JSON config option general.preRun, which is executed before fastfetch prints output.
  - It can be used to generate a temp logo file. For example
  Bugfixes:
  * Fix invalid path (#1031, LM, Linux)
  * Fix VMEM detection for Nvidia GPU (requires --gpu-driver-specific) (GPU)
  * Fix AMD --gpu-driver-specific for AMD cards (#1032, GPU, Windows)
  * Use Coordinated Universal Time rather than timezone-varying local date (#1046)
  Logo:
  * Fix colors of Asahi Linux
* Wed Jun 19 2024 Gordon Leung <pirateclip@protonmail.com>
- update to 2.16.0
  Changes:
  * Fastfetch now prefers `/etc/os-release` over `/etc/lsb-release` when detecting distro info.
  - This may break some distros (notably some debian based distros).
    File a bug with the content of `os-release` and `lsb-release` if it breaks your distro.
  Features:
  * Add new option `--users-myself-only` to display current login user only (Users)
  * Add new module `DNS` to show active DNS servers (DNS)
  * Add new option `--loadavg-compact`. Defaults to true (Loadavg)
  - Use `--loadavg-compact false` to display load averages in different lines
  * Detect MTU size (LocalIP)
  * Support version detection of pluma, which is the default editor of OpenIndiana (Editor)
  * Print used OGL library, eg EGL, GLX or OSMesa (OpenGL)
  Bugfixes:
  * Report error if cache size is unavailable (CPUCache, Android)
  * Trim white spaces in device name (Sound, Linux)
  * Fix `display.bar.border{Left,Right}` doesn't work in JSON config files (Config)
  * Fix invalid call to `realpath(3)` (Platform, Linux)
* Fri Jun  7 2024 Gordon Leung <pirateclip@protonmail.com>
- add pkgconfig(DirectX-Headers) to BuildRequires
  * This ensures that correect GPU info is shown when used by WSL
* Fri Jun  7 2024 RN <R_Nik_C@proton.me>
- update to 2.15.0
  Changes:
  * --bar-border <?bool> has been changed to --bar-border-left <string>
    and --bar-border-right <string>, which are used for customizing the style of bar border.
  - --bar-border-left '' --bar-border-right '' can be used to disable the border
  Features:
  * Add ability to skip installing license with INSTALL_LICENSE option (CMake)
  * Make it possible to shorten the theme and icons output (Theme / Icons)
  * Support -l '?' to show a question mark (Logo)
  * Add new module CPUCache to display CPU cache sizes (CPUCache)
  * In --<module>-format, {#keys} and {#title} can be used to reference the color of keys and title
  * Improve speed of Guix package detection (Packages, Linux)
  * Assume wm plugins are daemon processes to improve performance (WM, macOS)
  Bugfixes:
  * Remove shebangs from completions (#980)
  * Fix white chars not visible in terminal of light theme (Logo)
  * Normalize bright colors to fix color display in Apple Terminal (#991, Colors)
  * Correctly capitalize GNOME (#997, DE, Linux)
  * Fix segfault on system using turkish language (#995, InitSystem, Linux)
  * Fix kubuntu detection (#1000, OS, Linux)
  * Don't display duplicate entries (OS, Linux)
* Thu May 30 2024 Gordon Leung <pirateclip@protonmail.com>
- update to 2.14.0
  Features:
  * Support monochrome bar type
  * Apply default color palettes in --file and --data (Logo)
  * Support named variable placeholders in custom module formattion string
  - --title-format '{user-name-colored}{at-symbol-colored}{host-name-colored}'
    is equivalent to --title-format '{6}{7}{8}'
  * Support named color placeholders in custom module formattion string
  - --<module>-format '{#red}' is equivalent to --<module>-format '{#31}'
  - '{#red}' or '{#31}' is preferred over \u001b[31m because is more readable
    and --pipe aware (will be ignored in pipe mode)
  - Supported in Custom module too
  - See fastfetch -h format for detail
  * Add new module InitSystem, which detects the name of init system
  - i.e. process name of pid1. init, systemd, etc
  * Add option --color-separator to set the color of key-value separators
  * Print error reason when vulkan init fails (Vulkan)
  Bugfixes:
  * Don't detect .conf files in --list-config-paths
  * Fix outputColor doesn't work if module keys are disabled
* Sat May 25 2024 Gordon Leung <pirateclip@protonmail.com>
- update to 2.13.2:
  Bugfixes:
  - Remove DRM driver version detection feature,
    which caused a performance regression for nouveau drivers (Display, Linux)
  - Don't use *-unknown as display name for Wayland protocol (Display, Linux)
  Features:
  - Add new module Editor which prints editor settings, i.e. $VISUAL or $EDITOR
* Wed May 22 2024 Gordon Leung <pirateclip@protonmail.com>
- update to 2.13.1:
  Changes:
  * The long deprecated flag based config files are removed.
  - They can still be used with xargs fastfetch < /path/to/config.conf
  - --gen-config can be used to migrate them to json based config files
  * The long deprecated options --set and --set-keyless are removed.
  * Kernel module now prints kernel name by default
  Features:
  * Support st terminal font detection for font configuration compiled in st binary (TerminalFont, Linux)
  * Add option --color-output to change output color of all modules except Title, Separator
    display.color.output in JSONC config file
  * Add option --<module>-output-color to change output color of one specified module,
    which overrides the global option --color-output
  * Add option --publicip-ipv6 to print IPv6 address (PublicIP)
  * Add new module Loadavg to print load averages (Loadavg)
  * Add new module PhysicalMemory to print information of physical memory devices (PhysicalMemory)
    Requires root permission to work on Linux and FreeBSD
  * Support specifying --logo-width only for --kitty-direct and --iterm (Logo)
  * Add option --localip-show-all-ips to show all IPs assigned to the same interface (LocalIP)
    Default to false
  * Add --cpu-show-pe-core-count to detect and display core count for performance / efficiency cores (CPU)
  * Add new module Bootmgr which prints information of stage 2 bootloader (grub, system-boot, etc)
  - Requires booting in UEFI mode
  * Detect core count for performance / efficiency cores (CPU)
  - Test it with fastfetch --cpu-show-pe-core-count
  * Detect DRM driver version if DRM detection method is used (GPU, Linux)
  Bugfixes:
  * Rename option --temperature-unit to --temp-unit as documented in help messages
  * Fix alternate logo doesn't work with { "type": "builtin" } (Logo)
  * Don't detect clifm and valgrind as a terminal (Terminal, Linux)
  * Fix --cpu-freq-ndigits not working if --cpu-format is used
  Logos:
  * Add openSUSE Slowroll
* Mon May  6 2024 Gordon Leung <pirateclip@protonmail.com>
- update to 2.11.5:
  Changes:
  * Fastfetch will print a colorless ascii logo in --pipe mode for better lolcat compatibility.
    fastfetch | lolcat should work and no --pipe false needed. Previously the logo would be disabled in --pipe mode.
  * --os-file was removed and CMake option -DCUSTOM_OS_RELEASE_PATH=/path/to/os-release was added.
    This option should not used in most cases.
  Bugfixes:
  * Fix possible out-of-bound memory access (#868)
  * Fix doubled output in custom formation (#852)
  * Fix memory leaks when passing informative options
  * Fix JSON config size.ndigits doesn't work
  * Remove --os-file in help messages
  Features:
  * Enable --pipe mode if environment variable $NO_COLOR is set
  * Support Armbian and Proxmox distro detection (OS, Linux)
* Sun May  5 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- update to 2.11.3:
  * Features:
  - Add cmake option CUSTOM_AMDGPU_IDS_PATH for specifying custom path of amdgpu.ids
  * Bugfixes:
  - Fix hanging when detecting disconnected network drive (Disk, Windows)
  - Ensure line ending is printed when printing image logo errors (Logo)
  - Revert image logo limitation change in 2.11.2; allow image logo in SSH session and tmux again (#861, Logo)
  - Fix doubled output in custom formation (PhysicalDisk, Windows)
- changes that are from 2.11.2:
  * Changes:
  - Error messages when trying to print image logo will only be printed with --show-errors
  - When generating JSON output, fastfetch will generate an empty array when no result is detected, instead of an error.
  * Bugfixes:
  - Fix segfault in Debian 11 and some old kernels. Regression introduced in 2.11.0 (#845, GPU, Linux)
  - Don't try detecting version of raw sh shell (#849, Shell, Linux)
  - Trim \r on Windows
  * Features:
  - Check xdg state home for nix user packages (#837, Packages, Linux)
  - Disable image logos in ssh and tmux sessions (#839)
  - Support MX Linux distro detection (#847, OS, Linux)
  * Logo:
  - Add KernelOS
  - Fix name of DraugerOS
  - Add missing FF_LOGO_LINE_TYPE_SMALL_BIT flags
  - Add MX2
- changes that are from 2.11.2:
  * Bugfixes:
  - Fix uninitialized variables which can cause crashes (#760 #838, Battery, Android)
  - Don't detect hyfetch as shell when used as backend of hyfetch
  - Fix incorrect information in man page (#828)
  * Features:
  - Support sorcery package manager detection (Packages, Linux)
  - Make --custom-format optional (Custom)
  - Make / an alias of C:\ for --disk-folders (Disk, Windows)
  - Build for Linux armv7
  * Logo:
  - Fix colors of Source Mage logo
* Wed May  1 2024 Gordon Leung <pirateclip@protonmail.com>
- update to 2.11.0:
  Changes:
  - Default hideCursor to false. It doesn't make much difference
    but makes user's terminal unusable if fastfetch is not exited correctly.
  Bugfixes:
  - Fix minimum cmake version support
  - Fix wifi detection on platforms that don't use NetworkManager
  - Fix GPU type detection for AMD cards
  Features:
  - Add basic support DE detection support for UKUI (DE, Linux)
  - Make config specified in JSONC overridable by command line flags
  * Note this change only make global config overridable; module configs are still not
  - Suggest increasing --processing-timeout when child process timeouts
  - Only detect folders that specified by --disk-folders
  * Previously --disk-folders only omits unmatched disks from output.
    This option can be used to improve detection performance by ignoring slow network drives
* Tue Apr 23 2024 Gordon Leung <pirateclip@protonmail.com>
- update to 2.10.2:
  Changes:
  * We now always detect max frequency of GPUs for consistent, instead of current frequency
  Features:
  * Improve display detection for wlroots based WMs. Fastfetch now correctly reports fractional scale factors in hyprland (Display, Linux)
  * Improve GPU detection on Linux (GPU, Linux)
  - Support GPU memory usage detection for AMD GPUs
  - Support GPU frequency detection for Intel GPUs
  * Improve performance of Gnome version detection (DE, Linux)
  * Improve performance of kitty version detection (Terminal, Linux)
  * Detect refresh rate when using --ds-force-drm sysfs-only (Display, Linux)
  * Add option --ts-version to disable terminal and shell version detection. Mainly for benchmarking purposes
  * Improve performance of detecting WSL version (Host, Linux)
  Bugfixes:
  * Correctly detect /bin/sh as current shell if it's used as default shell (Shell, Linux)
  * Work around an issue which CPU module reports incorrect CPU frequency that is too high (CPU, Linux)
  * Don't print ANSI escape codes in --pipe mode
* Tue Apr 16 2024 Gordon Leung <pirateclip@protonmail.com>
- update to 2.9.2:
  Changes:
  * To make use of the newly introduced `yyjson` flag `YYJSON_WRITE_NEWLINE_AT_END`, fastfetch now requires `yyjson` 0.9.0 or later
  Features:
  * Always add a final new-line when generating JSON output
  * Detect partition create time, which can be used as OS installation time (Disk)
  * Print time string when generating JSON result instead of UNIX epoch time number, which is more human-readable
  Bugfixes:
  * Fix a memory leak
  * Fix parsing of option `--packages-disabled` (Packages)
  * Don't use command `time` as a shell (Shell)
  Logos:
  * Add openSUSE MicroOS
  * Fix color of AOSC OS
* Mon Apr  8 2024 Dirk Müller <dmueller@suse.com>
- update to 2.9.1:
  * Support weston-terminal (missed commit in v2.9.0)
    (TerminalFont, Linux)
  * Support hyprcursor detection
  * Fix `fastfetch --gen-config` raises SIGSEGV when
    `~/.config/fastfetch` doesn't exist. Regression of `2.9.0`
* Thu Apr  4 2024 Gordon Leung <pirateclip@protonmail.com>
- update to 2.9.0:
  Features:
  * Support Lxterminal version detection (Terminal, Linux)
  * Support weston-terminal version and font detection (TerminalFont, Linux)
  * Support am package manager detection (Packages, Linux)
  * Support network prefix length detection for IPv6 (LocalIP)
  * Display all IPs when multiple IPs are assigned to the same interface (LocalIP)
  * Add option --localip-show-prefix-len to show network prefix length for both IPv4 and IPv6. Defaults to true (LocalIP)
  Bugfixes:
  * Fix network prefix length detection when the value is greater than 24 (LocalIP, Linux)
  * For xfce4-terminal, use system mono font if no config file is found (TerminalFont, Linux)
* Mon Mar 25 2024 Gordon Leung <pirateclip@protonmail.com>
- update to 2.8.10:
  Bugfixes:
  * Ignore chezmoi (Terminal, Linux)
  * Trim trailing possible whitespaces (PublicIP)
  * Fix detection compatibility for KDE 6 (Font, Linux)
  Features:
  * Improve stability; print more useful error message; avoid misuse (PublicIP / Weather)
* Fri Mar 15 2024 Gordon Leung <pirateclip@protonmail.com>
- update to version 2.8.9:
  Bugfixes:
  * Don't detect SessionLeader as terminal, actually (Terminal, Linux)
  * Fix blurry chafa result when specifying both width and height (Logo)
  Features:
  * Distinguish min frequency and base frequency (CPU)
* Fri Mar  8 2024 Gordon Leung <pirateclip@protonmail.com>
- update to version 2.8.8:
  Bugfixes:
  * Fix old fish version compatibility
  * Fix truncated texts in --help format
  * Fix old vulkan-header and libdrm library compatibility (Linux)
  * Fix possible segfaults in --help *-format
  * Fix invalid resolution detection when using libdrm (Linux, Display)
  * Fix segfault when /sys/devices/system/cpu/cpufreq/ doesn't exist (CPU, Linux)
  * Don't detect SessionLeader as terminal (Terminal, Linux)
  * Fix detection of client IP (Users, Linux)
* Sat Mar  2 2024 Gordon Leung <pirateclip@protonmail.com>
- update to version 2.8.7:
  Bugfixes:
  * Fix max CPU frequency detection for some cases (CPU, Linux)
  * Fix some memory leaks
  * Fix ddcutil 2.1 compatibility (Brightness, Linux)
  Features:
  * Support zellij version detection (Linux, Terminal)
* Wed Feb 28 2024 Gordon Leung <pirateclip@protonmail.com>
- update to version 2.8.6:
  Changes:
  * Due to newly introduced configs, JSONC option { "temperatureUnit": "C" } has been changed to { "temp": { "unit": "C" } }
  Bugfixes:
  * Fix incorrect GPU name detection for Intel iGPU on Linux (GPU, Linux)
  Features:
  * Support additional temperature formatting options
    { "temp": { "ndigits": 1 } }
    { "temp": { "color": { "green": "green", "yellow": "yellow", "red": "red" } } }
  * Support specifying custom pci.ids path for Linux (GPU, Linux)
  * Support warp-linux terminal version & terminal font detection (Terminal, Linux)
* Fri Feb 23 2024 Gordon Leung <pirateclip@protonmail.com>
- update to version 2.8.5:
  Bugfixes:
  * Fix segfault if we fail to find Vendor ID in lscpu (CPU, Linux)
  * Fix multi-device bcachefs filesystem compatibility (Disk, Linux)
  Features:
  * Support --color-block-width and --color-block-range (Colors)
  * Support --diskio-detect-total to show total bytes read/written (DiskIO)
  * Support --netio-detect-total to show total bytes received/sent (NetIO)
  * Support --packages-disabled to disable specified package manager (Packages)
  * Support --display-order to sort multiple displays in a specific order (Display)
  * Support --display-compact-type original-with-refresh-rate to show refresh rates in compact / oneline mode (Display)
* Mon Feb 12 2024 Gordon Leung <pirateclip@protonmail.com>
- update to version 2.8.3:
  Bugfixes:
  * Fix GPU name detection for AMD graphic cards (GPU, Linux / FreeBSD)
* Sat Feb 10 2024 Gordon Leung <pirateclip@protonmail.com>
- update to version 2.8.0:
  Features:
  * Rewrite GPU module, drop libpci dependency (GPU, Linux)
  * Detect marketing name of Apple Silicon CPUs for asahi linux (CPU, Linux)
  * Add new module Camera, which prints the name and resolution of connected cameras
  Bugfixes:
  * Fix compatibility with packages installed by flatpak (Terminal, Linux)
  * Don't show not connected if no power adapter is found (macOS / Linux, PowerAdapter)
  * Make format of battery status be consistent with other platforms (Linux, Battery)
* Fri Feb  2 2024 Gordon Leung <pirateclip@protonmail.com>
- update to version 2.7.1:
  Features:
  * Config presets in app folder now work with symlinks
  Bugfixes:
  * Fix a possible segfault when detecting terminal (Terminal, Linux)
* Sun Jan 28 2024 Gordon Leung <pirateclip@protonmail.com>
- update to version 2.7.0:
  Changes:
  * Add new module TerminalTheme, which prints the foreground and background color of the current terminal window.
  * Allow command substitution when expanding paths
  * Improve xonsh shell detection (Shell)
  * Support colored percentage values (Bluetooth / Gamepad / Sound)
  * Add --<module>-percent-[green|yellow] options to specify threshold of percentage colors
  * Add --percent-color-[green|yellow|red] options to specify color of different percent value states.
  * Remove support of option --battery-dir. We detect a lot of things in /sys/class/*
    and only module Battery supports specifying a custom directory for some reason, which is weird.
  * Remove --chassis-use-wmi which is no longer used.
  * --gpu-use-nvml has been renamed to --gpu-driver-specific due to using of IGCL and AGS
  * We now detect external partitions more conservatively in Linux. USB partitions will not be detected as external always
  Features:
  * Default preset names to .jsonc. For example, fastfetch -c all will load presets/all.jsonc
  * Support more properties of physical disks (PhysicalDisk)
  * Support SSD temperature detection with --physicaldisk-temp (PhysicalDisk)
  * Support ash (default shell of BusyBox) version detection (Shell, Linux)
  * Support manufacture date and serial number detection for physical monitors (Monitor)
  * Support battery serial number and manufacturer date detection (Battery)
  * Support host serial number and UUID detection (Host)
  * Support battery level detection for gamepads where possible (Gamepad)
  Bugfixes:
  * Fix segfault in CPU module when running in aarch64 machine without lscpu installed (CPU, Linux)
  * Don't use login as terminal process (Terminal, Linux)
  * Create sub folders when writing config file
  * Fix Btrfs subvolumes being detected as external partitions some times (Linux, Disk)
  * Fix battery cycle counts in some places (Battery)
  * Fix physical monitor detection with Nvidia drivers (Monitor, Linux)
  * Fix locale module printing unexpected results in specific environments (Locale)
  For more info: https://github.com/fastfetch-cli/fastfetch/releases
* Sat Dec 23 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- update to version 2.4.0:
  * *BREAKING**
  We are deprecating flags based config files (will be removed in v3.0.0).
  We suggest you migrate to json based config files.
  One may use `-c /path/to/config.conf --gen-config` to migrate existing flag
  based config files.
  Changes:
  * All flag based presets are removed
  Features:
  * Improve performance of detecting rpm and pkg package count (Packages, Linux / FreeBSD)
  * Support Apple M3X temperature detection (CPU / GPU, macOS)
  * `--ds-force-drm` support a new option `sysfs-only`
  * Improve xfce4 version detection
  * Detect WM and DE by enumerating running processes (WM / DE, FreeBSD)
  * Add a new module `Physical Disk`, which detects product name, full size, serial number and so on.
  Bugfixes:
  * Fix crashes sometimes when `--logo-padding-top` is not set (Logo)
  * Fix memory usage counting algorithm (Memory, macOS)
  * Fix the behavior of `--no-buffer` in Windows
  * Fix possible segfault in some devices (Display, Linux)
  * Fix segfaults on first use of new images with Sixel flag (Image)
- update specfile:
  * add bash completion subpackage.
  * add fish completion subpackage.
  * add manpage for fastfetch for package.
* Tue Nov 21 2023 Dirk Müller <dmueller@suse.com>
- update to 2.2.3:
  * Update the latest mac models (Host, macOS)
  * Fix terminal detection on NixOS (Terminal)
  * `--percent-type` now defaults to 9 (colored percentage
    numbers)
  * `fastfetch` now prints LocalIp module by default
  * Features:
  * LocalIP module now prints netmask in CIDR format for IPv4
  * Bios module now detects system firmware type (Bios)
  * Improve detection of `Battery`
  * Detect cycle count on supported platforms
  * Detect temperature on Linux when supported
  * Status detection on macOS has been adjusted to be consistant
    with other platforms
  * Linux binaries are built with imagemagick7 support
  * Update NixOS_small
  * Hotfix release for #606
  * Fix broken presets due to the breaking changes introduced in
  * Features:
  * Pretty print `fastfetch --help`
  * This release introduces a new option `--migrate-config`,
    which migrates old flag based config file to new JSONC format
  * Changes:
  * `--pipe` and `--stat` are moved from `general` options to
    `display` options. This affects cjson configuration.
  * Display keys `percent*` and `size*` in JSON config are
    restructured. e.g. `{ "sizeNdigits": 1 }` is now `{ "size": {
    "ndigits": 1 } }`
  * With the introduction of `--migrate-config`, the old flag
    based config file is deprecated, and will be removed in 3.0.0
    (next major version)
  * Support of `--gen-config conf` is deprecated accordingly, and
    will be removed in 2.3.0 (next minor version)
  * The global flag `--allow-slow-operations` is splitted into
    some explicit flags in differnet modules
  * `--packages-winget`: control whether `winget` packages count
    should be detected. Note it's a very slow operation, please
    enable it with caution.
  * `--chassis-use-wmi`: control whether `WMI` query should be
    used to detect chassis type, which detects more information,
    but slower. This flag only affects `--chassis-format` and
    `--format json`.
  * `--battery-use-setup-api`: control whether `SetupAPI` should
    be used on Windows to detect battery info, which supports
    multi batteries, but slower.
  * `--wm-detect-plugin`: control whether WM plugins should be
    detected. Note it's implemented with global processes
    enumeration and can report false results.
  * `--de-slow-version-detection`: control DE version should be
    detected with slow operations. It's usually not necessary and
    only provided as a backup.
  * `--localip-default-route-only` and `--netio-default-route-
    only` defaults to true to avoid large number of results
  * Features:
  * Quirks for MIPS platforms (CPU, Linux)
  * Use devicetree path for OBP hosts (Host, Linux)
  * Detect `tmux: server` as tmux (Terminal, Linux)
  * Support urxvt version detection (Terminal, Linux)
  * Support st version detection (Terminal, Linux)
  * Support st terminal font detection (TerminalFont, Linux)
  * Support xfce4-terminal 1.1.0+ terminal font detection
    (TerminalFont, Linux)
  * Add option `--migrate-config <?target-file-path>`
  * Support Nvidia GPU temp and cuda core count detection via
    nvml. Use `--gpu-use-nvml` to enable it (GPU)
  * Try supporting Wifi authentication type detection in macOS
    Sonoma. Please file a feature request if you get `to be
    supported (num)` with result of `/System/Library/PrivateFrame
    works/Apple80211.framework/Resources/airport -I | grep auth`
    (Wifi, macOS)
  * Bugfixes:
  * Better GPU memory and type detection (GPU, Windows)
  * Don't print display type twice (Display)
  * Detect BSSID instead of Wifi MAC address to align with other
    platforms (Wifi, macOS)
  * Remove support of used GPU memory detection, which is not
    reliable and only supported with `--gpu-force-vulkan`. (GPU)
  * Fix flag `--brightness-ddcci-sleep` (Brightness, Linux)
  * Fix hanging if a child process prints to both stdout and
    stderr (Linux)
  * Logos:
  * Add Black Mesa
  * Add cycledream
  * Add Evolinx
  * Add azos
  * Add Interix
* Mon Oct 30 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Declare new build deps gcc and gcc-c++
- Update to version 2.1.2. Changes listed after 2.0.5:
    [#] 2.1.2
    Bugfixes:
  * Fix icon detection on Windows. It shows enabled system icons in desktop (`This PC`, `Recycle Bin`, etc) (Icon, Windows)
  * Fix compatibility with ddcutil 2.0 (Brightness, Linux)
  * Fix a compile warning (CPUUsage, FreeBSD)
    [#] 2.1.1
    Features:
  * Support opkg (Packages, Linux)
  * Support GNOME Console terminal version and font detection (Terminal, Linux)
  * Add `--cpu-freq-ndigits` to set number of digits for CPU frequency (CPU)
  * New module to detect physical disk I/O usage (DiskIO)
  * Add `--cpuusage-separate` to display CPU usage per CPU logical core
  * Add `--brightness-ddcci-sleep` to set the sleep times (in ms) when sending DDC/CI requests (Brightness, #580)
    Bugfixes:
  * Fix possible crashes on Windows 7 (Disk, Windows)
  * Fix possible crashes caused by uninitialized strings (Users, Windows)
  * Improve support of `--help *-format` and several bugs are found and fixed
  * Don't incorrectly print `No active sound devices found` when using a non-controllable sound device (Sound, macOS)
  * Fix implementation processes counting (Processes, Linux)
  * Work around a issue that SSID cannot be detected on macOS Sonoma (Wifi, macOS)
    Logo:
  * Add Chimera Linux
  * Add EndeavourSmall
  * Add Xenia
    [#] 2.1.0
    This release introduces a new output format: JSON result
    Changes:
  * Users module detects and prints user login time by default. Specifying `--users-compact` to disable it
  * Fastfetch now requires yyjson 0.8.0 or later, which is embeded in fastfetch source tree. If you build fastfetch with `-DENABLE_SYSTEM_YYJSON` cmake option, you must upgrade your yyjson package
  * Reduced information supported by `--terminal-format`, `--shell-format`
  * Some config presets (`devinfo` and `verbose`) are obseleted and removed. They are barely maintained and can be replaced with `--format json` now.
  * Custom strings in `--module-key` and `--module-format` are no longer trimmed.
  * `/boot` is hidden by default (FreeBSD, Disk)
    Features:
  * Add `--format json`, which prints system information as JSON format
  * Add fast path for xfce4 version detection (DE, FreeBSD)
  * Support contour terminal version and font detection (Terminal / TerminalFont)
  * Support `kitty-direct` / `iterm` without specifying logo width / height. Note: in this case, the entre screen will be cleared.
  * Support new flag `--logo-separate`. If true, print modules at bottom of the logo
  * Support Apple Silicon CPU frequency detection (CPU, macOS)
  * Support user login time detection (Users)
  * Support winget package manager detection, guarded behind `--allow-slow-operations` (Packages, Windows)
  * Print monitor type (built-in or external) (Display)
  * Support full GPU detection in WSL (Linux, GPU)
  * Add `--module-key " "` as a special case for hiding keys
  * Support `--title-format`. See `fastfetch --help title-format` for detail
  * Support `--colors-key` (Colors)
  * Add `-c` as a shortcut of `--load-config`. Note it was used as the shortcut of `--color` before 2.0.5
  * Support Windows Service Pack version detection (Kernel, Windows)
  * Support Debian point releases detection (OS, Linux)
  * Add new module `NetIO` which prints network throughput (usage) of specified interface. Note this module costs about 1 second to finish.
  * Use `lscpu` to detect CPU name for ARM CPUs (CPU, Linux)
    Bugfixes:
  * Fix fastfetch hanging in specific environment (#561)
  * Fix short read when reading from stdin (Logo)
  * Fix `poll() timeout or failed` error when image is very large (Logo)
  * Fix Termux Monet terminal version detection (Terminal)
  * Fix zpool volumes detection (Disk, Linux)
  * Fix external volumes detection (Disk, Linux)
  * Fix snap package number detection on systems other than Ubuntu (Packages, Linux)
  * Fix dpkg / apt package number detection (Packages, Linux)
  * Fix bluetooth mac address detection (Bluetooth, Windows)
    Logo:
  * Add Afterglow
  * Add Elbrus
  * Update EvolutionOS
  * Update AOSC OS
  * Update Ubuntu_old
  * Update Windows 11_small
  * Add Amazon Linux
  * Add LainOS
  * Fix colors of Slackware
* Mon Sep 18 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.0.5:
  * Bugfixes:
  - Fix segfault when using libxrandr (#544, Display, Linux)
  - Don't print 0px (#544, Cursor)
  * Features:
  - Add option --disk-use-available (#543)
  - Add option --disk-show-readonly
- Removed config.conf to fix build
* Tue Aug 22 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 2.0.1:
  * Changes:
  - Unescape strings only when parsing .conf files
  - Previously: $ NO_CONFIG=1 fastfetch --os-key \\\\ -s os -l none prints \: *.
    Note the backslashs are unescaped twice (once by shell and once by fastfetch).
  - Now: $ NO_CONFIG=1 fastfetch --os-key \\\\ -s os -l none prints \\: *
  - Remove option shortcut -c (alias of --color), which is more commonly used as alias of --config
  - Rename --recache to --logo-recache (which is used for regenerate image logo cache). Remove option shortcut -r (alias of --recache).
  - Detecting brightness of external displays with DDC/CI is no longer guarded behind --allow-slow-operations (Brightness)
  * Features:
  - Add --key-width for aligning the left edge of values, supported both for global --key-width and specific module --module-key-width
  - Add --bar-char-elapsed, --bar-char-total, --bar-width and --bar-border options
  - Add CMake option ENABLE_SYSTEM_YYJSON, which allow building fastfetch with system-provided yyjson (for package managers)
  - Add new module Version, which prints fastfetch version (like fastfetch --version)
  * Bugfixes:
  - Fix label detection. Use --disk-key 'Disk ({2})' to display it (Disk, Linux)
  - Fix some module options were not inited
  - Fix terminal version and font detection on NixOS (Terminal, Linux)
* Fri Jul 21 2023 Dirk Müller <dmueller@suse.com>
- update to 1.12.2:
  * Support terminator terminal version detection (Linux,
    Terminal)
  * Support `pkgtool` package manager detection (Linux, Packages)
  * Support `Far` shell version detection (Windows, Shell)
  * Fix ConEmu terminal detection in some special cases (Windows,
    Terminal, #488)
  * Fix incorrect Host on M2 Mac Studio with M2 Max CPU (macOS,
    Host, #490)
  * Support KDE / LXQT / MATE / Cinnamon wallpaper detection
    (Wallpaper, Linux)
  * Support QTerminal version & terminal font detection
  * Support MATE Terminal version & terminal font detection
  * Set `--pipe true` automatically if stdout is not a tty
  * Detect new macs released on WWDC 2023 (macOS, Host)
  * Count cached memory as free memory (FreeBSD, Memory)
  * Support sound detection (FreeBSD, Sound)
  * Fix `--logo-padding-left` doesn't work when `--logo-padding-
    top` is set (Logo)
  * Fix KDE version detection on Fedora (DE)
  * Include limits.h when needed (Linux, #472)
  * Fix Windows drives detection in WSL (Linux, Disk)
  * Fix crash on newer wayland desktops (Linux, Display, #477)
* Mon Jun 12 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.11.3:
  Features:
  * Support display name, type, rotation detection on Wayland (Linux, Display)
  * Print more useful display name instead of intel_backlight (Linux, Brightness)
  * Icons module supports Windows (Windows, Icons)
  * Add Wallpaper module which shows the current wallpaper image path
  * Add mac address detection --localip-show-mac (LocalIP, #451)
  Bugfixes:
  * Fix Gnome version detection on Fedora (DE)
  * Fix Windows drives detection in WSL (Disk)
  * Fix a segfault bug, regression of 1.11.1
  Changes:
  * In order to make Icons module consistant between different platforms,
  - -icons-format no longer supports individual GTK / QT icon params.
  * --theme-format no longer supports individual GTK / plasma theme params.
  * --local-ip-* and --public-ip-* have been changed to --localip-* and --publicip-*
  * --localip-compact-type is no longer supported. Fastfetch now display IPs as
  - -localip-compat-type multiline by default, with --local-compact true can be set as an alias of --localip-compact-type oneline
  * --localip-v6first is no longer supported.
* Wed May 17 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Move configuration files based on openSUSE distribution.
* Wed May 17 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.11.0:
  * Support linuxbrew
  * Support foot terminal
  * Support cursor size detection on Windows
  * Support cursor detection on macOS
  * Support display name, display type and decimal refresh rate detection
  * Support --display-compact-type to display multiple resolutions in one line
  * Support flatpak-user
  * Support --gpu-force-vulkan to force using vulkan to detect GPUs, which support video memory usage detection with --allow-slow-operations
  * Fix date time format
  * Fix compiling with musl
  * Don't exit if libpci is failed to init
  * Names of most well-known gamepads are correctly printed instead of Wireless Controller on Windows
  * Small update for nobara logo
* Sat Mar  4 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.10.3:
  * Fix uninitialized variables (GPU, Windows)
  * Fix compiling errors (Windows)
  * Improve performance (WmTheme amd Font, Windows and macOS)
  * Enable nonblocking public-ip / weather detection (Android)
* Thu Feb  2 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.9.1:
  * Fix builds on s390x (@jonathanspw, #402)
  * Fix zero refresh rate on some monitors (macOS)
  * Fix default formatting of Wifi module
* Mon Jan 23 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.9.0
  * fastfetch no longer creates a sample config file silently. Use --gen-config to generate one.
  * fastfetch now search for user config file in the order of fastfetch --list-config-paths
  * Unknown disks are hidden by default.
  * Resolution module is renamed to Display.
  * new options: --logo-padding-top, --list-config-paths, --list-data-paths, --gpu-hide-integrated, --gpu-hide-discrete
  * Raw image file as logo support
  * Add Brightness, Wifi module support
  * Disk name support for Linux
  * Fix rpm package count detection
  * Fix cpu temp detection
* Wed Jan 18 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.8.2. Changes since then to this version:
  * 1.8.2:
  - Fix memleaks Users module (Windows)
  - Fix shell detection when installed with scoop (Windows)
  - Don't use libcJSON as wlanapi's dll name (Windows)
  - Align artifact names to other platforms (Windows)
  * 1.8.1:
  - Bios / Board / Chassis modules are splitted against Host module for performance reasons
  - Caching is removed. Option --nocache is removed accordingly
  - Windows (7 and newer) is officially and fully supported
  - FreeBSD support is improved greatly (Bios, Cpu Temp, Cpu Usage, Disk, Host, Processes, Swap, Terminal / Shell, Uptime)
  - Adds a new flag --stat, which prints time usage for individual modules
  - Adds Wifi module which supports Windows and macOS
  - Adds data source option for logo printing
  - Detects Homebrew Cellar and Cask seperately
  - Detects WSL version
  - Detects disk based on mount point
  - Exposes more chafa configs
  - Improves performance for Cpu Usage, Public IP, Weather modules
  - Improves performance for Kitty image protocol when both image width / height specified
  - Improves performance for large file loading
  - Improves performance for macOS WM and Host detection
  - Improves shell and terminal detection on macOS
  - Supports Deepin Terminal terminal font
  - Supports GPU detection on Android
  - Supports Kitty Terminal terminal font
  - Supports bar output for percentage values
  - Supports Bios module on macOS
  - Supports eopkg package manager detection
  - Supports iTerm image logo protocol
  - Supports image logo printing on macOS
  - Supports tcsh version detection
  - Vulkan module on macOS no longer requires vulkan-loader to work
  - Fixes disk size detection on 32bit Linux (#337)
  - Fixes cpu freq detection in WSL
  - Fixes internal bug of FFstrbuf
  - Fixes some memory leaks
  - Fixes segfault if 0 is given as argument index
  - Lots of code refactors
  - Added new logos:
  * Alpine
  * CRUX
  * EndeavourOS
  * Enso
  * Garuda small
  * Nobara
  * OpenMandriva
  * Parabola GNU/Linux-libre
  * Rocky
  * Rosa
  * Solus
  * Univalent
  * Vanilla OS
* Wed Dec  7 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for fastfetch 1.7.5
